/* * * * * * * * * * * * * * * * * * * * * * *
* Returns whether the live game has started.
*
* @return           Has game started or not.
* * * * * * * * * * * * * * * * * * * * * * * */
native HasGameStarted( )


/* * * * * * * * * * * * * * * * * * * * * * *
* Returns whether the specified team is the last one alive.
*
* @param iTeam     Specified team.
*
* @return          True on success, false otherwise.
* * * * * * * * * * * * * * * * * * * * * * * */
native IsLastTeam( iTeam )


/* * * * * * * * * * * * * * * * * * * * * * *
* Returns number of alive players in a specified team.
*
* @param iTeam     Specified team.
*
* @return          Number of alive players.
* * * * * * * * * * * * * * * * * * * * * * * */
native GetTeamAlivePlayers( iTeam )


/* * * * * * * * * * * * * * * * * * * * * * *
* Returns number of remaining teams (alive).
*
* @return          Number of teams.
* * * * * * * * * * * * * * * * * * * * * * * */
native GetRemainingTeams( )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Round Starts.
* * * * * * * * * * * * * * * * * * * * * * * */
forward RoundStarted( )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player opens airdrop.
*
* @param id       Player who opens the airdrop.
* @param iEnt     Airdrop entity index
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerOpenAirDrop( id, iEnt )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player jumps from the airplane
*
* @param id       Player who jumped.
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerJumpPlane( id )

/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player is forced to jump from the airplane.
*
* @param id       Player who jumped
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerUrgentJump( id )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player deploys parachute.
*
* @param id       Player who deployed the parachute.
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerDeployParachute( id )

/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player opens backpack.
*
* @param id       Player who opened backpack.
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerOpenBackpack( id )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player uses a heal.
*
* @param id       Player who used a heal.
* @param iType     Heal type that he used.
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerUseHeal( id, iType )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Player picks-up a heal.
*
* @param id       Player who picked up a heal.
* @param iType     Type of heal he picked.
* * * * * * * * * * * * * * * * * * * * * * * */
forward PlayerPickUpHeal( id, iType )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when Red Zone appears.
* * * * * * * * * * * * * * * * * * * * * * * */
forward RedZoneAppear( )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when the last player of a team dies.
*
* @param id       Last player of the team.
* @param iTeam    Team of the player.
* * * * * * * * * * * * * * * * * * * * * * * */
forward TeamDead( id, iTeam )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when a player wins the round
*
* @param iTeam     Team of the player
* * * * * * * * * * * * * * * * * * * * * * * */
forward RoundWinner( iTeam )


/* * * * * * * * * * * * * * * * * * * * * * *
* Forward called when round ends
*
* * * * * * * * * * * * * * * * * * * * * * * */
forward RoundEnded( )